@@ -122,13 +122,17 @@ class Canvas(FigureCanvasAgg):
         # Ne pas utiliser directement.
         # Si on met la valeur a True, self.rafraichir_affichage() fonctionne toujours,
         # mais les changements ne s'affichent pas  l'cran.
-        # Cela permet d'effectuer un certain nombre d'actions sans que l'utilisateur s'en apercoive (pas de clignotement de l'affichage).
+        # Cela permet d'effectuer un certain nombre d'actions sans que l'utilisateur s'en apercoive
+        # (pas de clignotement de l'affichage).
         # Par contre, le gain de temps est ngligeable par rapport  un vrai gel de l'affichage.
         # En particulier, cela sert pour exporter une figure.
 
 
         self.graph = Moteur_graphique(self)
-        self.parametres = [u"taille", u"gradu", u"afficher_axes", u"afficher_quadrillage", u"afficher_fleches", u"repere", u"resolution", u"origine_axes", u"utiliser_repere", u"quadrillages", u"couleur_papier_millimetre", u"liste_axes", u"orthonorme", u"grille_aimantee", u"zoom_texte", "zoom_ligne"]
+        self.parametres = [u"taille", u"gradu", u"afficher_axes", u"afficher_quadrillage",
+                           u"afficher_fleches", u"repere", u"resolution", u"origine_axes",
+                           u"utiliser_repere", u"quadrillages", u"couleur_papier_millimetre",
+                           u"liste_axes", u"orthonorme", u"grille_aimantee", u"zoom_texte", "zoom_ligne"]
         self.liste_objets_en_gras = WeakList()
         self.initialiser()
 
@@ -222,6 +226,9 @@ class Canvas(FigureCanvasAgg):
     def codage_angle(self, **kw):
         return self.graph.codage_angle(**kw)
 
+    def rectangle(self, **kw):
+        return self.graph.rectangle(**kw)
+
     def dessiner(self, objet):
         self.graph.ajouter(objet)
 
@@ -379,12 +386,16 @@ def %(_nom_)s(self, valeur = no_argument):
 
 
 
-
     def _get_fenetre(self):
-        if self.orthonorme:
+        if self.orthonorme or getattr(self, 'ratio', None) is not None:
+            if self.orthonorme:
+                rat = 1
+            else:
+                rat = self.ratio # x:y -> x/y
+                # ratio est le rapport "unit en abscisse/unit en ordonne"
             w, h = self.dimensions
             fenetre = self.feuille_actuelle.fenetre
-            coeff0 = (fenetre[1] - fenetre[0])/w
+            coeff0 = rat*(fenetre[1] - fenetre[0])/w
             coeff1 = (fenetre[3] - fenetre[2])/h
             xmin, xmax, ymin, ymax = fenetre
             xcoeff = (coeff1/coeff0 if coeff0 < coeff1 else 1)
@@ -392,13 +403,6 @@ def %(_nom_)s(self, valeur = no_argument):
             x, y, rx, ry = (xmin+xmax)/2., (ymin+ymax)/2., (xmax-xmin)/2., (ymax-ymin)/2.
             return x - xcoeff*rx, x + xcoeff*rx, y - ycoeff*ry, y + ycoeff*ry
         return self.feuille_actuelle.fenetre
-##        if hasattr(self, 'ratio'): #  CRIRE
-##            if self.ratio is not None: # ratio est le
-##                xcoeff = (self.coeff(1)/(self.ratio*self.coeff(0)) if self.ratio*self.coeff(0) < self.coeff(1) else 1)
-##                ycoeff = (1 if (self.ratio*self.coeff(0)) < self.coeff(1) else (self.ratio*self.coeff(0))/self.coeff(1))
-##                xmin, xmax, ymin, ymax = self.fenetre
-##                x, y, rx, ry = (xmin+xmax)/2., (ymin+ymax)/2., (xmax-xmin)/2., (ymax-ymin)/2.
-##                self._changer_fenetre(x - xcoeff*rx, x + xcoeff*rx, y - ycoeff*ry, y + ycoeff*ry)
 
 
     def _set_fenetre(self, xmin_xmax_ymin_ymax):
@@ -558,15 +562,18 @@ def %(_nom_)s(self, valeur = no_argument):
     @track
     def repere_Oij(self, event = None):
         self.repere = ('O', 'i', 'j')
+        self.gerer_parametre_afficher_axes(True)
 
     @track
     def repere_OIJ(self, event = None):
         self.repere = ('O', 'I', 'J')
+        self.gerer_parametre_afficher_axes(True)
 
     @track
     def repere_011(self, event = None):
         ux, uy = self.gradu
         self.repere = ('0', str(ux), str(uy))
+        self.gerer_parametre_afficher_axes(True)
 
 
     @track
@@ -575,6 +582,7 @@ def %(_nom_)s(self, valeur = no_argument):
                             ((0.5, 0.5), '-', 0.25, 'darkgray'),
                             ((0.1, 0.1), '-', 0.1, 'gray'),
                             )
+        self.gerer_parametre_afficher_quadrillage(True)
 
     @track
     def quadrillage_millimetre_colore(self, event = None, couleur = None):
@@ -584,6 +592,7 @@ def %(_nom_)s(self, valeur = no_argument):
                                     ((0.5, 0.5), '-', 0.25, couleur),
                                     ((0.1, 0.1), '-', 0.1, couleur),
                                     )
+        self.gerer_parametre_afficher_quadrillage(True)
 
     @track
     def quadrillage_demigraduation(self, event = None):
@@ -591,6 +600,7 @@ def %(_nom_)s(self, valeur = no_argument):
         self.quadrillages = (  ((ux, uy), ':', 1, 'k'),
                                     ((ux/2, uy/2), '-', 0.25, 'darkgray'),
                                     )
+        self.gerer_parametre_afficher_quadrillage(True)
 
     @track
     def quadrillage_demigraduation_colore(self, event = None, couleur = None):
@@ -600,10 +610,52 @@ def %(_nom_)s(self, valeur = no_argument):
         self.quadrillages = (  ((ux, uy), ':', 1, couleur),
                                     ((ux/2, uy/2), '-', 0.25, couleur),
                                     )
+        self.gerer_parametre_afficher_quadrillage(True)
 
     @track
     def quadrillage_defaut(self, event = None):
         self.quadrillages = self.param("quadrillages", defaut = True)
+        self.gerer_parametre_afficher_quadrillage(True)
+
+
+# Slection d'une zone
+######################
+
+    def gestion_zoombox(self, pixel):
+        x, y = pixel
+        xmax, ymax = self.dimensions
+        x = max(min(x, xmax), 0)
+        y = max(min(y, ymax), 0)
+        self.fin_zoom = self.pix2coo(x, y)
+        self.debut_zoom = self.debut_zoom or self.fin_zoom
+        (x0, y0), (x1, y1) = self.debut_zoom, self.fin_zoom
+        if self.orthonorme or getattr(self, 'ratio', None) is not None:
+            rymax = (ymax if self.orthonorme else ymax*self.ratio)
+            if rymax*abs(x0 - x1) > xmax*abs(y0 - y1):
+                y1 = y0 + rymax/xmax*abs(x0 - x1)*cmp(y1, y0)
+            else:
+                x1 = x0 + xmax/rymax*abs(y0 - y1)*cmp(x1, x0)
+            self.fin_zoom = (x1, y1)
+            #if param.bouger_curseur:  # ou comment rendre fou l'utilisateur... ;)
+            #    self.WarpPointer(*self.XYcoo2pix((x1, y1), -1))
+        self.dessiner_polygone([x0,x0,x1,x1], [y0,y1,y1,y0], facecolor='c', edgecolor='c', alpha = .1)
+        self.dessiner_ligne([x0,x0,x1,x1,x0], [y0,y1,y1,y0,y0], 'c', alpha = 1)
+
+        self.rafraichir_affichage(dessin_temporaire = True) # pour ne pas tout rafraichir
+
+
+    def selection_zone(self, pixel):
+        x, y = pixel
+        xmax, ymax = self.dimensions
+        x = max(min(x, xmax), 0)
+        y = max(min(y, ymax), 0)
+        self.fin_select = self.pix2coo(x, y)
+        self.debut_select = self.debut_select or self.fin_select
+        (x0, y0), (x1, y1) = self.debut_select, self.fin_select
+        self.dessiner_polygone([x0,x0,x1,x1], [y0,y1,y1,y0], facecolor='y', edgecolor='y',alpha = .1)
+        self.dessiner_ligne([x0,x0,x1,x1,x0], [y0,y1,y1,y0,y0], 'g', linestyle = ":", alpha = 1)
+
+        self.rafraichir_affichage(dessin_temporaire = True) # pour ne pas tout rafraichir
 
 
 # Evenements concernant directement la feuille
